# TODO Copyright
#

"""Command line parsing"""

import argparse

from srsync import VERSION
from srsync.profile import do_profile

def do_exec(args):
    """Manage 'exec' command"""
    print("TODO", args)

def do_mark(args):
    """Manage 'mark' command"""
    print("TODO", args)

def do_print(args):
    """Manage 'print' command"""
    print("TODO", args)

def do_status(args):
    """Manage 'status' command"""
    print("TODO", args)


def cmd_line_parser():
    """Return a command line parser"""
    parser = argparse.ArgumentParser()
    parser.add_argument(
        '-v', '--version',
        action='version',
        version='%(prog)s {version}'.format(version=VERSION),
        )
    subparsers = parser.add_subparsers(title='Commands', dest='command')
    subparsers.required = True
    subparsers.dest = 'command'

    # Exec
    cmd_exec = subparsers.add_parser(
        'exec',
        help='Update configuration and synchronize files',
        formatter_class=argparse.RawDescriptionHelpFormatter,
        )
    cmd_exec.set_defaults(func=do_exec)
    cmd_exec_subparser = cmd_exec.add_subparsers(
        title='Exec',
        dest='subcommand',
        )
    cmd_exec_subparser.required = True

    cmd_exec_rsync = cmd_exec_subparser.add_parser(
        'rsync',
        help='Update configuration and synchronise files',
        )

    cmd_exec_print = cmd_exec_subparser.add_parser(
        'print',
        help=(
            'Update configuration and print the command that would have been '
            'executed with "exec rsync".'
            ),
        )

    # Print
    cmd_print = subparsers.add_parser(
        'print',
        help='Update configuration and print information about files.',
        formatter_class=argparse.RawDescriptionHelpFormatter,
        )
    cmd_print.set_defaults(func=do_print)
    cmd_print_subparser = cmd_print.add_subparsers(
        title='print',
        dest='subcommand',
        )
    cmd_print_subparser.required = True

    cmd_print_list = cmd_print_subparser.add_parser(
        'list',
        help='Print the list of files that would be synchronised.'
        )

    cmd_print_nlist = cmd_print_subparser.add_parser(
        'nlist',
        help='Print the list of files that would not be synchronised.'
        )

    cmd_print_none = cmd_print_subparser.add_parser(
        'none',
        help='Do not print anything (update only).'
        )

    # Rsync
    cmd_rsync = subparsers.add_parser(
        'rsync',
        help='Alias for "exec rsync"',
        formatter_class=argparse.RawDescriptionHelpFormatter,
        )

    # Mark
    cmd_mark = subparsers.add_parser(
        'mark',
        help='Mark (or forget mark about) files.',
        )
    cmd_mark.set_defaults(func=do_mark)
    cmd_mark_subparser = cmd_mark.add_subparsers(
        title='mark',
        dest='subcommand',
        )
    cmd_mark_subparser.required = True

    cmd_mark_accept = cmd_mark_subparser.add_parser(
        'accept',
        help='Mark the paths for being accepted.',
        )

    cmd_mark_ask = cmd_mark_subparser.add_parser(
        'ask',
        help='Mark the paths for action "ask".',
        )

    cmd_mark_forget = cmd_mark_subparser.add_parser(
        'forget',
        help='Forget configuration of path.',
        )

    cmd_mark_reject = cmd_mark_subparser.add_parser(
        'reject',
        help='Mark the paths for not being accepted.',
        )

    # Profile
    cmd_profile = subparsers.add_parser(
        'profile',
        help='Manage profiles',
        )
    cmd_profile.set_defaults(func=do_profile)
    cmd_profile_subparser = cmd_profile.add_subparsers(
        title='profile',
        dest='subcommand',
        )
    cmd_profile_subparser.required = True

    cmd_profile_list = cmd_profile_subparser.add_parser(
        'list',
        help='List all available profiles',
        )

    cmd_profile_new = cmd_profile_subparser.add_parser(
        'new',
        help='Create new empty profile NAME. ',
        )

    cmd_profile_copy = cmd_profile_subparser.add_parser(
        'copy',
        help='Copy existing profile SRC to new profile DEST. ',
        )

    cmd_profile_delete = cmd_profile_subparser.add_parser(
        'delete',
        help='Delete existing profile NAME. ',
        )

    # Status
    cmd_status = subparsers.add_parser(
        'status',
        help='Print status (mark set on) given files.',
        )
    cmd_status.set_defaults(func=do_status)

    return parser
